MediaBottomSheet class

Adaptive modal bottom sheet and action dialog for selecting media sources.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show(BuildContext context, {PickerOptions options = const PickerOptions()}) Future<ImageSource?>
Displays an adaptive picker sheet (Cupertino on iOS, Material 3 on Android, dialog on Web/Desktop).
showUrlInputDialog(BuildContext context, {String? initialValue, String title = 'Import Image from URL', String hintText = 'https://example.com/photo.jpg'}) Future<String?>
Displays a dialog prompting the user to enter a web image URL.