pickImages method
Picks one or more images from the device gallery/photo picker.
Implementation
Future<List<AdaptiveFile>> pickImages(PickerOptions options) {
throw UnimplementedError('pickImages() has not been implemented.');
}
Picks one or more images from the device gallery/photo picker.
Future<List<AdaptiveFile>> pickImages(PickerOptions options) {
throw UnimplementedError('pickImages() has not been implemented.');
}