registerWith static method
Registers this class as the default instance of AdaptiveImagePickerPlatform.
Implementation
static void registerWith(Registrar registrar) {
AdaptiveImagePickerPlatform.instance = AdaptiveImagePickerWeb();
}
Registers this class as the default instance of AdaptiveImagePickerPlatform.
static void registerWith(Registrar registrar) {
AdaptiveImagePickerPlatform.instance = AdaptiveImagePickerWeb();
}