AdaptiveImagePickerPlatform class abstract
The interface that implementations of adaptive_image_picker must implement.
- Inheritance
-
- Object
- PlatformInterface
- AdaptiveImagePickerPlatform
- Implementers
Constructors
- AdaptiveImagePickerPlatform()
- Constructs an AdaptiveImagePickerPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> - Returns the platform version string (for diagnostics).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickImages(
PickerOptions options) → Future< List< AdaptiveFile> > - Picks one or more images from the device gallery/photo picker.
-
takePhoto(
PickerOptions options) → Future< AdaptiveFile?> - Captures a photo using the device camera.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AdaptiveImagePickerPlatform
-
The default instance of AdaptiveImagePickerPlatform to use.
getter/setter pair