AdaptiveImagePickerWeb class
A web implementation of the AdaptiveImagePickerPlatform of the AdaptiveImagePicker plugin.
- Inheritance
-
- Object
- PlatformInterface
- AdaptiveImagePickerPlatform
- AdaptiveImagePickerWeb
Constructors
- AdaptiveImagePickerWeb()
- Constructs a AdaptiveImagePickerWeb
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
Returns the platform version string (for diagnostics).
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pickImages(
PickerOptions options) → Future< List< AdaptiveFile> > -
Picks one or more images from the device gallery/photo picker.
override
-
takePhoto(
PickerOptions options) → Future< AdaptiveFile?> -
Captures a photo using the device camera.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void - Registers this class as the default instance of AdaptiveImagePickerPlatform.